@@ -93,7 +93,7 @@ namespace HGW {
     void collectReadsAndCoverage(Segs::ReadCollection &col, htsFile *bam, sam_hdr_t *hdr_ptr,
                                  hts_idx_t *index, int threads, Utils::Region *region,
                                  bool coverage, std::vector<Parse::Parser> &filters, BS::thread_pool &pool,
-                                 const int parse_mods, int sortReadsBy);
+                                 int parse_mods);
 
     void iterDrawParallel(Segs::ReadCollection &col,
                           htsFile *b,
@@ -123,11 +123,11 @@ namespace HGW {
 
     void trimToRegion(Segs::ReadCollection &col, bool coverage, int snp_threshold);
 
-    void refreshLinked(std::vector<Segs::ReadCollection> &collections, Themes::IniOptions &opts, int *samMaxY, int sortReadsBy);
+    void refreshLinked(std::vector<Segs::ReadCollection> &collections, std::vector<Utils::Region> &regions, Themes::IniOptions &opts, int *samMaxY);
 
     void appendReadsAndCoverage(Segs::ReadCollection &col, htsFile *bam, sam_hdr_t *hdr_ptr,
                                 hts_idx_t *index, Themes::IniOptions &opts, bool coverage, bool left, int *samMaxY,
-                                std::vector<Parse::Parser> &filters, BS::thread_pool &pool, int sortReadsBy);
+                                std::vector<Parse::Parser> &filters, BS::thread_pool &pool, Utils::Region &region);
 
     struct EndIdx {
         int end, size, index;
