@@ -19,13 +19,6 @@
 #include "termcolor.h"
 #include "GLFW/glfw3.h"
 
-//#ifdef __APPLE__
-//    #include <OpenGL/gl.h>
-//#elif defined(__linux__)
-//    #include <GL/gl.h>
-//    #include <GL/glx.h>
-//#endif
-
 #define SK_GL
 #include "include/gpu/GrBackendSurface.h"
 #include "include/gpu/GrDirectContext.h"
@@ -66,7 +59,7 @@ void print_banner() {
 }
 
 // note to developer - update version in workflows/main.yml, menu.cpp, term_out.cpp, and deps/gw.desktop, and installers .md in docs
-const char GW_VERSION [7] = "1.0.3";
+const char GW_VERSION [7] = "1.1.0";
 
 
 bool str_is_number(const std::string &s) {
@@ -221,6 +214,9 @@ int main(int argc, char *argv[]) {
     program.add_argument("--filter")
             .default_value(std::string{""}).append()
             .help("Filter to apply to all reads");
+    program.add_argument("-c", "--command")
+            .default_value(std::string{""}).append()
+            .help("Apply command before drawing e.g. -c 'sort strand'");
     program.add_argument("--delay")
             .default_value(0).append().scan<'i', int>()
             .help("Delay in milliseconds before each update, useful for remote connections");
@@ -548,6 +544,11 @@ int main(int argc, char *argv[]) {
         filters = Utils::split(program.get("--filter"), ';');
     }
 
+    std::vector<std::string> extra_commands;
+    if (program.is_used("--command")) {
+        extra_commands = program.get<std::vector<std::string>>("--command");
+    }
+
     if (!iopts.no_show) {  // plot something to screen
         if (use_session) {
             mINI::INIFile file(iopts.session_file);
@@ -645,9 +646,12 @@ int main(int argc, char *argv[]) {
         plotter.rasterCanvas = rasterSurface->getCanvas();
         plotter.rasterSurfacePtr = &rasterSurface;
 
+
         // start UI here
         if (!program.is_used("--variants") && !program.is_used("--images")) {
-            int res = plotter.startUI(sContext, sSurface, program.get<int>("--delay"));  // plot regions
+            int res = plotter.startUI(sContext, sSurface,
+                                      program.get<int>("--delay"),
+                                      extra_commands);  // plot regions
             if (res < 0) {
                 std::cerr << "ERROR: Plot to screen returned " << res << std::endl;
                 std::exit(-1);
@@ -670,7 +674,9 @@ int main(int argc, char *argv[]) {
             }
             plotter.mode = Manager::Show::TILED;
 
-            int res = plotter.startUI(sContext, sSurface, program.get<int>("--delay"));
+            int res = plotter.startUI(sContext, sSurface,
+                                      program.get<int>("--delay"),
+                                      extra_commands);
             if (res < 0) {
                 std::cerr << "ERROR: Plot to screen returned " << res << std::endl;
                 std::exit(-1);
@@ -700,7 +706,9 @@ int main(int argc, char *argv[]) {
 
             plotter.mode = Manager::Show::TILED;
 
-            int res = plotter.startUI(sContext, sSurface, program.get<int>("--delay"));
+            int res = plotter.startUI(sContext, sSurface,
+                                      program.get<int>("--delay"),
+                                      extra_commands);
             if (res < 0) {
                 std::cerr << "ERROR: Plot to screen returned " << res << std::endl;
                 std::exit(-1);
@@ -767,6 +775,12 @@ int main(int argc, char *argv[]) {
                     plotter.fb_width = iopts.dimensions.x;
                     plotter.fb_height = iopts.dimensions.y;
                     plotter.setRasterSize(plotter.fb_width, plotter.fb_height);
+                    if (!extra_commands.empty()) {
+                        for (const auto& command: extra_commands) {
+                            plotter.inputText = command;
+                            plotter.commandProcessed();
+                        }
+                    }
                     plotter.runDrawOnCanvas(pageCanvas);
                     pdfDocument->close();
                     buffer.writeToStream(&out);
@@ -776,6 +790,12 @@ int main(int argc, char *argv[]) {
                     plotter.setRasterSize(plotter.fb_width, plotter.fb_height);
                     SkPictureRecorder recorder;
                     SkCanvas* canvas = recorder.beginRecording(SkRect::MakeWH(iopts.dimensions.x, iopts.dimensions.y));
+                    if (!extra_commands.empty()) {
+                        for (const auto& command: extra_commands) {
+                            plotter.inputText = command;
+                            plotter.commandProcessed();
+                        }
+                    }
                     plotter.runDrawOnCanvas(canvas);
                     sk_sp<SkPicture> picture = recorder.finishRecordingAsPicture();
                     std::unique_ptr<SkCanvas> svgCanvas = SkSVGCanvas::Make(SkRect::MakeWH(iopts.dimensions.x, iopts.dimensions.y), &out);
@@ -794,7 +814,18 @@ int main(int argc, char *argv[]) {
                     sk_sp<SkSurface> rasterSurface = SkSurface::MakeRasterN32Premul(iopts.dimensions.x,
                                                                                     iopts.dimensions.y);
                     SkCanvas *canvas = rasterSurface->getCanvas();
-                    if (iopts.link_op == 0) {
+                    bool stream_reads = iopts.link_op == 0;
+                    if (!extra_commands.empty()) {
+                        plotter.regionSelection = 0;
+                        for (const auto& command: extra_commands) {
+                            plotter.inputText = command;
+                            plotter.commandProcessed();
+                            if (plotter.regions.front().sortOption != 0) {
+                                stream_reads = false;
+                            }
+                        }
+                    }
+                    if (stream_reads) {
                         plotter.runDrawNoBufferOnCanvas(canvas);
                     } else {
                         plotter.runDrawOnCanvas(canvas);
@@ -877,20 +908,21 @@ int main(int argc, char *argv[]) {
                                               Manager::GwPlot *plt = managers[this_block];
                                               plt->makeRasterSurface();
                                               std::vector<Utils::Region> &all_regions = jobs[this_block];
-//                                              sk_sp<SkSurface> rasterSurface = SkSurface::MakeRasterN32Premul(
-//                                                      iopts.dimensions.x, iopts.dimensions.y);
-//                                              SkCanvas *canvas = rasterSurface->getCanvas();
+
                                               for (auto &rgn: all_regions) {
                                                   plt->collections.clear();
                                                   delete plt->regions[0].refSeq;
                                                   plt->regions[0].chrom = rgn.chrom;
                                                   plt->regions[0].start = rgn.start;
                                                   plt->regions[0].end = rgn.end;
-                                                  if (iopts.link_op == 0) {
-                                                      plt->runDrawNoBuffer();
-                                                  } else {
-                                                      plt->runDraw();
+                                                  if (!extra_commands.empty()) {
+                                                      for (const auto& command: extra_commands) {
+                                                          plt->inputText = command;
+                                                          plt->commandProcessed();
+                                                      }
                                                   }
+                                                  plt->runDrawNoBuffer();
+
                                                   sk_sp<SkImage> img(plt->rasterSurface->makeImageSnapshot());
                                                   std::filesystem::path fname = "GW~" + plt->regions[0].chrom + "~" +
                                                                    std::to_string(plt->regions[0].start) + "~" +
@@ -1014,8 +1046,19 @@ int main(int argc, char *argv[]) {
                                             for (int i = a; i < b; ++i) {
                                                 Manager::VariantJob job = jobs[i];
                                                 plt->setVariantSite(job.chrom, job.start, job.chrom2, job.stop);
-//                                                plt->runDrawNoBuffer();
-                                                if (plt->opts.link_op == 0) {
+
+                                                bool stream_reads = iopts.link_op == 0;
+                                                if (!extra_commands.empty()) {
+                                                    plt->regionSelection = 0;
+                                                    for (const auto& command: extra_commands) {
+                                                        plt->inputText = command;
+                                                        plt->commandProcessed();
+                                                        if (plt->regions.front().sortOption != 0) {
+                                                            stream_reads = false;
+                                                        }
+                                                    }
+                                                }
+                                                if (stream_reads) {
                                                     plt->runDrawNoBuffer();
                                                 } else {
                                                     plt->runDraw();
