@@ -2,7 +2,6 @@
 #include <array>
 #include <chrono>
 #include <cstdlib>
-#include <deque>
 #include <filesystem>
 #include <mutex>
 #include <string>
@@ -11,12 +10,6 @@
 
 #include <glad.h>
 
-//#ifdef __APPLE__
-//    #include <OpenGL/gl3.h>
-//#elif defined(__linux__)
-//    #include <GL/gl.h>
-//    #include <GL/glx.h>
-//#endif
 
 #include "htslib/faidx.h"
 #include "htslib/hts.h"
@@ -151,7 +144,7 @@ namespace Manager {
             pool.reset(opts.threads);
         }
         triggerClose = false;
-        sortReadsBy = Manager::SortType::NONE;
+//        sortReadsBy = Manager::SortType::NONE;
 
     }
 
@@ -243,6 +236,7 @@ namespace Manager {
         }
         bool opengl_es_loader = false;
         glfwWindowHint(GLFW_OPENGL_PROFILE, GLFW_OPENGL_CORE_PROFILE);
+        glfwWindowHint(GLFW_SCALE_TO_MONITOR, GLFW_TRUE);
 
 #ifndef __APPLE__  // linux, windows, termux
     #ifdef USE_GL
@@ -255,7 +249,7 @@ namespace Manager {
         glfwWindowHint(GLFW_CLIENT_API, GLFW_OPENGL_ES_API);
         glfwWindowHint(GLFW_CONTEXT_CREATION_API, GLFW_EGL_CONTEXT_API);
         glfwWindowHint(GLFW_CONTEXT_VERSION_MAJOR, (major_v == -1) ? 2 : major_v);
-        glfwWindowHint(GLFW_CONTEXT_VERSION_MINOR, (minor_v == -1) ? 0 : major_v);
+        glfwWindowHint(GLFW_CONTEXT_VERSION_MINOR, (minor_v == -1) ? 0 : minor_v);
 
         opengl_es_loader = true;
     #endif
@@ -348,6 +342,15 @@ namespace Manager {
             std::cerr << "OpenGL renderer: " << rend << std::endl;
             std::cerr << "OpenGL version: " << ver << std::endl;
             std::cerr << "OpenGL vendor: " << ven << std::endl;
+            float xscale;
+            float yscale;
+            int windX, windY;
+            glfwGetWindowContentScale(window, &xscale, &yscale);
+            glfwGetFramebufferSize(window, &fb_width, &fb_height);
+            glfwGetWindowSize(window, &windX, &windY);
+            std::cerr << "Content x-scale=" << xscale << " y-scale=" << yscale << std::endl;
+            std::cerr << "Window width=" << windX << " height=" << windY << std::endl;
+            std::cerr << "Framebuffer width=" << width << " height=" << height << std::endl;
         }
 
         if (rasterSurfacePtr == nullptr) {
@@ -607,11 +610,11 @@ namespace Manager {
         }
         if (opts.seshIni["show"].has("sort")) {
             if (opts.seshIni["show"]["sort"] == "none") {
-                sortReadsBy = SortType::NONE;
+//                sortReadsBy = SortType::NONE;  // todo
             } else if (opts.seshIni["show"]["sort"] == "strand") {
-                sortReadsBy = SortType::STRAND;
+//                sortReadsBy = SortType::STRAND;
             } else if (opts.seshIni["show"]["sort"] == "hap") {
-                sortReadsBy = SortType::HP;
+//                sortReadsBy = SortType::HP;
             }
         }
         if (!reference.empty()) {
@@ -723,10 +726,10 @@ namespace Manager {
         int windX, windY;
         glfwGetWindowSize(window, &windX, &windY);
         opts.saveCurrentSession(reference, ideogram_path, bam_paths, track_paths, regions, variant_paths_info,
-                                commandsApplied, output_session, mode, xpos, ypos, monitorScale, windX, windY, sortReadsBy);
+                                commandsApplied, output_session, mode, xpos, ypos, monitorScale, windX, windY, 0);  // todo sortReadBy
     }
 
-    int GwPlot::startUI(GrDirectContext *sContext, SkSurface *sSurface, int delay) {
+    int GwPlot::startUI(GrDirectContext *sContext, SkSurface *sSurface, int delay, std::vector<std::string> &extra_commands) {
         if (!opts.session_file.empty() && reference.empty()) {
             std::cout << "Loading session: " << opts.session_file << std::endl;
             loadSession();
@@ -745,9 +748,17 @@ namespace Manager {
 	    normalCursor = glfwCreateStandardCursor(GLFW_ARROW_CURSOR);
 
         fetchRefSeqs();
-        fetchRefSeqs();
+
         opts.theme.setAlphas();
         GLFWwindow *wind = this->window;
+
+        if (!extra_commands.empty()) {
+            for (const auto& command: extra_commands) {
+                inputText = command;
+                commandProcessed();
+            }
+        }
+
         if (mode == Show::SINGLE) {
             printRegionInfo();
         } else {
@@ -762,13 +773,14 @@ namespace Manager {
         }
         bool wasResized = false;
         redraw = true;
-
+        processed = false;
+        glfwSwapInterval(1);
         std::chrono::high_resolution_clock::time_point autoSaveTimer = std::chrono::high_resolution_clock::now();
         while (true) {
             if (glfwWindowShouldClose(wind) || triggerClose) {
                 break;
             }
-            glfwWaitEvents();
+
             if (delay > 0) {
                 std::this_thread::sleep_for(std::chrono::milliseconds(delay));
             }
@@ -839,9 +851,15 @@ namespace Manager {
             if (!resizeTriggered) {
                 drawOverlay(sSurface->getCanvas());
             }
-
             sContext->flush();
             glfwSwapBuffers(window);
+            redraw = false;
+
+            if (frameId == 1) {  // This is a fix for wayland, not sure why its needed
+                glfwPostEmptyEvent();
+            }
+
+            glfwWaitEvents();
 
             while (imageCacheQueue.size() > 100) {
                 imageCacheQueue.pop_front();
@@ -921,12 +939,14 @@ namespace Manager {
                         }
                     }
 
-                    if (reg->end - reg->start < opts.low_memory || opts.link_op != 0 || sortReadsBy != SortType::NONE) {
-                        HGW::collectReadsAndCoverage(collections[idx], b, hdr_ptr, index, opts.threads, reg,
-                                                     (bool) opts.max_coverage, filters, pool, parse_mods_threshold, sortReadsBy);
+                    if (reg->end - reg->start < opts.low_memory || opts.link_op != 0) {
 
+                        HGW::collectReadsAndCoverage(collections[idx], b, hdr_ptr, index, opts.threads, reg,
+                                                     (bool) opts.max_coverage, filters, pool, parse_mods_threshold);
+
+                        int sort_state = Segs::getSortCodes(collections[idx].readQueue, opts.threads, pool, reg);
                         int maxY = Segs::findY(collections[idx], collections[idx].readQueue, opts.link_op, opts,
-                                               false, sortReadsBy);
+                                               false, sort_state);
                         samMaxY = maxY;
                     } else {
                         samMaxY = opts.ylim;
@@ -1005,9 +1025,7 @@ namespace Manager {
             yScaling = (trackY - gap) / (double)samMaxY;
 
             // Ensure yScaling is an integer if possible
-            if (yScaling > 1 && sortReadsBy == SortType::NONE) {
-//                yScaling = (int)yScaling;
-//                yScaling = (std::floor((yScaling*2)+0.5)/2);
+            if (yScaling > 1) {
                 yScaling = std::ceil(yScaling);
             }
         } else {
@@ -1019,17 +1037,14 @@ namespace Manager {
             pH = trackY / (float) opts.ylim;
             yScaling *= 0.95;
         } else {
-//            std::cout << "yscaling " << yScaling << " monior scale " << monitorScale  << std::endl;
-//            if (yScaling > 9*monitorScale) {
-//                pH = yScaling - (2 * monitorScale);//* 0.85;  // polygonHeight
-//            } else
             if (yScaling > 3*monitorScale) {
                 pH = yScaling - monitorScale;
             } else {
                 pH = yScaling;
             }
         }
-        if (pH > 8 && sortReadsBy == SortType::NONE) {  // scale to pixel boundary
+
+        if (pH > 8) {  // scale to pixel boundary
             pH = (float)(int)pH;
         } else if (opts.tlen_yscale) {
             pH = std::fmax(pH, 8);
@@ -1125,8 +1140,9 @@ namespace Manager {
                 }  // else no clip
                 canvasR->drawPaint(opts.theme.bgPaint);
 
-                if (!cl.skipDrawingReads) {
-                    if (cl.regionLen >= opts.low_memory && !bams.empty() && opts.link_op == 0 && sortReadsBy == SortType::NONE) {
+                if (!cl.skipDrawingReads && !bams.empty()) {
+                    if (cl.regionLen >= opts.low_memory) {
+                        assert (opts.link_op == 0 && regions[cl.regionIdx].getSortOption() == SortType::NONE);
                         // low memory mode will be used
                         cl.clear();
                         if (opts.threads == 1) {
@@ -1227,6 +1243,8 @@ namespace Manager {
                 return;
             }
             canvas->drawImage(imageCacheQueue.back().second, 0, 0);
+        } else {
+            canvas->drawPaint(opts.theme.bgPaint);
         }
 
         // slider overlay
@@ -1773,12 +1791,12 @@ namespace Manager {
 
             if (!cl.skipDrawingReads) {
                 if (opts.threads == 1) {
-                    std::chrono::high_resolution_clock::time_point initial = std::chrono::high_resolution_clock::now();
+//                    std::chrono::high_resolution_clock::time_point initial = std::chrono::high_resolution_clock::now();
                     HGW::iterDraw(cl, bams[cl.bamIdx], headers[cl.bamIdx], indexes[cl.bamIdx],
                                   &regions[cl.regionIdx], (bool) opts.max_coverage,
                                   filters, opts, canvas, trackY, yScaling, fonts, refSpace, pointSlop,
                                   textDrop, pH, monitorScale);
-                    std::cerr << " time runDrawNoBufferOnCanvas " << (std::chrono::duration_cast<std::chrono::milliseconds >(std::chrono::high_resolution_clock::now() - initial).count()) << std::endl;
+//                    std::cerr << " time runDrawNoBufferOnCanvas " << (std::chrono::duration_cast<std::chrono::milliseconds >(std::chrono::high_resolution_clock::now() - initial).count()) << std::endl;
                 } else {
                     HGW::iterDrawParallel(cl, bams[cl.bamIdx], headers[cl.bamIdx], indexes[cl.bamIdx],
                                           opts.threads, &regions[cl.regionIdx], (bool) opts.max_coverage,
