@@ -63,7 +63,7 @@ namespace Term {
         out << termcolor::green << "settings                         " << termcolor::reset << "Open the settings menu'\n";
 		out << termcolor::green << "snapshot, s      path?           " << termcolor::reset << "Save current window to png e.g. 's', or 's view.png',\n                                 or vcf columns can be used 's {pos}_{info.SU}.png'\n";
         out << termcolor::green << "soft-clips, sc                   " << termcolor::reset << "Toggle soft-clips\n";
-        out << termcolor::green << "sort             strand/hap      " << termcolor::reset << "Sort reads by strand or haplotype\n";
+        out << termcolor::green << "sort             strand/hap/pos  " << termcolor::reset << "Sort reads by strand, haplotype, and/or pos\n";
         out << termcolor::green << "tags                             " << termcolor::reset << "Print selected sam tags\n";
         out << termcolor::green << "theme            igv/dark/slate  " << termcolor::reset << "Switch color theme e.g. 'theme dark'\n";
         out << termcolor::green << "tlen-y                           " << termcolor::reset << "Toggle --tlen-y option\n";
@@ -78,6 +78,7 @@ namespace Term {
         out << "zoom in              " << termcolor::bright_yellow; Term::printKeyFromValue(opts.zoom_in, out); out << "\n" << termcolor::reset;
         out << "zoom out             " << termcolor::bright_yellow; Term::printKeyFromValue(opts.zoom_out, out); out << "\n" << termcolor::reset;
         out << "zoom to cursor       " << termcolor::bright_yellow; out << "CTRL + LEFT_MOUSE" << "\n" << termcolor::reset;
+        out << "sort at cursor       " << termcolor::bright_yellow; out << "S" << "\n" << termcolor::reset;
         out << "decrease ylim        " << termcolor::bright_yellow; out << "CTRL + KEY_MINUS" << "\n" << termcolor::reset;
         out << "increase ylim        " << termcolor::bright_yellow; out << "CTRL + KEY_EQUALS" << "\n" << termcolor::reset;
         out << "next region view     " << termcolor::bright_yellow; Term::printKeyFromValue(opts.next_region_view, out); out << "\n" << termcolor::reset;
@@ -281,10 +282,13 @@ namespace Term {
         } else if (s == "soft-clips" || s == "sc") {
             out << "    Toggle soft-clips.\n        Soft-clipped bases or hard-clips are turned on or off.\n\n";
         } else if (s == "sort") {
-            out << "    Sort reads by strand or haplotype (defined by HP tag in bam file).\n\n"
+            out << "    Sort reads by strand, haplotype (defined by HP tag in bam file), or pos.\n\n"
                    "    Examples:\n"
                    "        sort hap\n"
-                   "        sort strand\n\n";
+                   "        sort strand\n"
+                   "        sort 6400234       # Sorting based on genomic position\n"
+                   "        sort strand 120000 # By strand and then position\n"
+                   "        sort hap 120000    # Haplotype then position\n";
         } else if (s == "tags") {
             out << "    Print selected sam tags.\n        This will print all the tags of the selected read\n\n";
         } else if (s == "theme") {
@@ -1386,7 +1390,7 @@ namespace Term {
     }
 
 #if !defined(__EMSCRIPTEN__)
-    const char* CURRENT_VERSION = "v1.0.3";
+    const char* CURRENT_VERSION = "v1.1.0";
 
     size_t WriteCallback(void* contents, size_t size, size_t nmemb, void* userp) {
         ((std::string*)userp)->append((char*)contents, size * nmemb);
