@@ -8,6 +8,8 @@
 #include "defaultIni.hpp"
 #include "ankerl_unordered_dense.h"
 
+#include "include/core/SkFontMgr.h"
+
 #if !defined(__EMSCRIPTEN__)
     #include <curl/curl.h>
     #include <curl/easy.h>
@@ -559,8 +561,8 @@ namespace Themes {
             vt["low_memory"] = "1500000";
             update_ini = true;
         }
-        if (vt.has("mod_threshold")) {
-            mod_threshold = std::stoi(vt["mod_threshold"]);
+        if (vt.has("mod")) {
+            mod_threshold = std::stoi(vt["mod"]);
         } else {
             vt["mod"] = "1000000";
         }
@@ -987,6 +989,23 @@ namespace Themes {
         file.generate(seshIni, true);
     }
 
+    void printAvailableFonts() {
+        sk_sp<SkFontMgr> fontManager = SkFontMgr::RefDefault();
+        int familyCount = fontManager->countFamilies();
+        std::cerr << "Available font families:" << std::endl;
+        std::vector<std::string> fontFamilies;
+        for (int i = 0; i < familyCount; ++i) {
+            SkString familyName;
+            fontManager->getFamilyName(i, &familyName);
+            fontFamilies.push_back(familyName.c_str());
+        }
+        std::sort(fontFamilies.begin(), fontFamilies.end());
+        for (const auto& family : fontFamilies) {
+            std::cerr << family << std::endl;
+        }
+        std::cerr << "Total font families: " << familyCount << std::endl;
+    }
+
     const SkGlyphID glyphs[1] = {100};
 
     EXPORT Fonts::Fonts() {
@@ -997,7 +1016,37 @@ namespace Themes {
     }
 
     void Fonts::setTypeface(std::string &fontStr, int size) {
-        face = SkTypeface::MakeFromName(fontStr.c_str(), SkFontStyle::Normal());
+
+        if (fontStr == "Default") {
+            face = SkTypeface::MakeDefault();
+            if (!face) {
+                std::cerr << "Error: failed to create font. Text will likely be missing\n";
+            }
+        } else {
+            const char * font_c = fontStr.c_str();
+            face = SkTypeface::MakeFromName(font_c, SkFontStyle::Normal());
+            if (!face) {
+                face = SkTypeface::MakeDefault();
+                SkString familyName;
+                face->getFamilyName(&familyName);
+                std::cerr << "\nWarning: font '" << fontStr << "' could not be loaded, using system default instead '" << familyName.c_str() << ". et GW_DEBUG=1 to display available fonts.\n";
+                char *val = getenv("GW_DEBUG");
+                if (val) {
+                    printAvailableFonts();
+                }
+            } else {
+                SkString familyName;
+                face->getFamilyName(&familyName);
+                if (familyName.c_str() != fontStr) {
+                    std::cerr << "\nWarning: font '" << fontStr << "' could not be loaded, swapped for '" << familyName.c_str() << " instead. Set GW_DEBUG=1 to display available fonts.\n";
+                    char *val = getenv("GW_DEBUG");
+                    if (val) {
+                        printAvailableFonts();
+                    }
+                }
+            }
+        }
+
         SkScalar ts = size;
         fonty.setSize(ts);
         fonty.setTypeface(face);
